@@ -47,23 +47,45 @@ macro_rules! assert_ata {
     };
 }
 
-/// Asserts that two accounts share the same key.
+/// Asserts that the given account matches the program id.
 #[macro_export]
 macro_rules! assert_program {
-    ($account_a: expr, $program_id: tt $(,)?) => {
-        let __account_a = anchor_lang::Key::key(&$account_a);
+    ($account: expr, $program_id: tt $(,)?) => {
+        let __account = anchor_lang::Key::key(&$account);
         let __program_id: Pubkey = $crate::program_ids::$program_id;
-        if __account_a != __program_id {
+        if __account != __program_id {
             msg!(
                 "Program ID mismatch: expected {}, found {}",
                 __program_id,
-                __account_a
+                __account
             );
             return Err($crate::VipersError::ProgramIDMismatch.into());
         }
     };
 }
 
+/// Asserts that an account is owned by the given program.
+#[macro_export]
+macro_rules! assert_owner {
+    ($program_account: expr, $owner: expr $(,)?) => {
+        assert_owner!($program_account, $owner, "owner mismatch")
+    };
+    ($program_account: expr, $owner: expr, $msg: expr $(,)?) => {
+        let __program_account =
+            *anchor_lang::ToAccountInfo::to_account_info(&$program_account).owner;
+        let __owner = anchor_lang::Key::key(&$owner);
+        if __program_account != __owner {
+            msg!(
+                "Owner mismatch: {}: expected {}, got {}",
+                $msg,
+                __program_account,
+                __owner
+            );
+            return Err($crate::VipersError::OwnerMismatch.into());
+        }
+    };
+}
+
 /// Ensures an [Option] can be unwrapped, otherwise returns the error
 #[macro_export]
 macro_rules! unwrap_or_err {
@@ -113,6 +135,12 @@ mod tests {
     use anchor_spl::token;
     use spl_associated_token_account::get_associated_token_address;
 
+    #[account]
+    #[derive(Default)]
+    struct TestData {
+        pub byte: u8,
+    }
+
     #[test]
     fn test_compiles() -> ProgramResult {
         assert_keys!(token::ID, token::ID, "token program");
@@ -131,4 +159,28 @@ mod tests {
 
         Ok(())
     }
+
+    #[test]
+    fn test_assert_owner() -> ProgramResult {
+        let key = Pubkey::new_unique();
+        let mut lamports: u64 = 8 + (TestData::default().try_to_vec().unwrap().len() as u64);
+
+        let mut buffer: [u8; 16] = [0; 16];
+        let mut buf: &mut [u8] = &mut buffer;
+        TestData::default().try_serialize(&mut buf)?;
+
+        let info: CpiAccount<TestData> = CpiAccount::try_from(&AccountInfo::new(
+            &key,
+            false,
+            false,
+            &mut lamports,
+            &mut buffer,
+            &key,
+            false,
+            0,
+        ))?;
+        assert_owner!(info, key);
+
+        Ok(())
+    }
 }
